TonWalletBridgePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • TonWalletBridgePlatform
Implementers

Constructors

TonWalletBridgePlatform()
Constructs a TonWalletBridgePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchAssets({required String address, bool testnet = false}) Future<Map<String, dynamic>>
generateMnemonic() Future<List<String>>
generateV4Wallet({required List<String> mnemonic, int workchain = 0, bool useBip39 = true, int index = 0}) Future<Map<String, dynamic>>
getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TonWalletBridgePlatform
The default instance of TonWalletBridgePlatform to use.
getter/setter pair